@@ -43,8 +43,10 @@ def _create_where(equality_constraints, interval_constraints):
 
 
 class LocalDB_Connector:
-    def __init__(self,
-                 server: str = '', user: str = '', password: str = '', db: str = ''):
+    def __init__(self):
+        return
+
+    def open(self, server: str = '', user: str = '', password: str = '', db: str = ''):
         self.conn = psycopg2.connect(database=db,
                                      host=server,
                                      user=user,
