@@ -94,7 +94,7 @@ def create_where(equality_constraints, interval_constraints):
     for name in interval_constraints:
         values = interval_constraints[name]
         tmp = [(name, value1, value2) for value1, value2 in values if value1 or value2]
-        print(tmp)
+        # print(tmp)
         ans = ' or '.join([f"{name} between {value1} and {value2}" if value1 and value2 else
                             f"{name} >= {value1}" if value1 else
                             f"{name} <= {value2}" for name, value1, value2 in tmp])
@@ -118,7 +118,7 @@ def query_init(start_date, features=True, targets=True, filters=None):
     # for key in alias:
     #     filters = filters.replace(key, alias[key])
     # filters = f"where {filters}" if filters else ""
-    filters = f" {filters} and" if filters else ""
+    filters = f" {filters} and ROWNUM <= 100000" if filters else "ROWNUM <= 100000"
 
     count = "*"
     if not features and not targets:
@@ -434,14 +434,16 @@ def query_init(start_date, features=True, targets=True, filters=None):
     )
     where
     {features} {filters}
-    ROWNUM <= 100000
     order by КОН_ПРОКАТ
 
 '''
 
 
 class OracleDB_Connector:
-    def __init__(self, user_oracle = '', password_oracle = '', dsn_oracle = ''):
+    def __init__(self):
+        return
+
+    def open(self, user_oracle = '', password_oracle = '', dsn_oracle = ''):
 
         # cx.init_oracle_client(lib_dir= r'C:/Program Files/Oracle/instantclient_21_3')
         self.cx_conn = cx.connect(user=user_oracle, password=password_oracle, dsn=dsn_oracle)
